/* genWave: generates the wave form into a short array
 * Implements sine and rectangular wave forms which is selected by an argument
 * to the function
 * copyright U. Raich 2017
 * This program is part of the workshop on embedded systems held at 
 * the University of Cape Coast in the winter semester 2017
 * It has been released under the GNU General Public License
 * see gnu.org/licenses/gpl.html
 */
#include <stdio.h>
#include <math.h>
#include "genWave.h"

unsigned short wave[100];

unsigned short *genWave(enum waveType wt) {
  int i;
  if (wt==rect) {
    for (i=0;i<WAVE_FORM_LENGTH; i++) {
      wave[i] = (i<WAVE_FORM_LENGTH/2) ? 0 : WAVE_FORM_RESOLUTION;
    }
  }
  else
    if (wt==sine) {
      for (i=0; i< WAVE_FORM_LENGTH; i++) {
	/*
	  sin(x) with x in radians, gives me values between -1 and 1
	  If I want 100 values of the sin functions in equal intervals in x
	  I divide 2*M_PI by 100 and multiply this by the index
	  This gives me:
	  (2*M_PI/100)*1
	  (2*M_PI/100)*2
	  (2*M_PI/100)*2 ...
	  (2*M_PI/100)*100 = 2*M_PI
	    
	  since my DAC take values between 0 and 4095 I have to map the 
	  sin values to this range:
	  dacValue = (sinValue+1)*(RESOLUTION/2)
	*/
	wave[i]=(sin(2*M_PI*i/100.0) + 1)*WAVE_FORM_RESOLUTION/2.0;
      }
    }
  return(wave);
}
